@@ -1149,12 +1149,12 @@ public class RootTree : Tree {
 					}
 			
 			string contrib = (oldContrib + contribs) == 1?"There is {0} contribution":"There are {0} contributions";
-			con.Insert (0, String.Format (contrib, oldContrib + contribs) + " for uploading <i>(File--&gt; Contributions--&gt; Upload)</i>", 1);
+			con.Insert (0, String.Format (contrib, oldContrib + contribs) + " pending upload <i>(Contributing--&gt; Upload)</i>", 1);
 			con.Append ("</ul>");
 			if (oldContrib == 1)
-				con.Append ("<i>You have 1 contribution that is not listed below and will be send the next time you upload contributions. Only contributions made from now on will be listed.</i>");
+				con.Append ("<i>You have 1 contribution that is not listed below that will be sent the next time you upload contributions. Only contributions made from now on will be listed.</i>");
 			else if (oldContrib > 1)
-				con.Append ("<i>You have " + oldContrib + "contributions that are not listed below and will be send the next time you upload contributions. Only contributions made from now on will be listed.</i>");
+				con.Append ("<i>You have " + oldContrib + "contributions that are not listed below and will be sent the next time you upload contributions. Only contributions made from now on will be listed.</i>");
 
 			//start the rendering
 			if (!HelpSource.use_css) {
@@ -1167,9 +1167,9 @@ public class RootTree : Tree {
 				sb.Append ("<br><table bgcolor=\"#fff3f3\" width=\"100%\" cellpadding=\"5\"><tr><td>");
 				sb.Append ("<h5>Contributions</h5><br>");
 				if ((oldContrib + contribs) == 0) {
-					sb.Append ("<p><b>You don't have any contribution yet.</b></p>");
-					sb.Append ("<p>The Documentation of the libraries is not complete and your contributions would be greatly apreciated. The procedure is easy, browse to the part of the documentation you want to contribute and click on the <font color=\"blue\">[Edit]</font> link to start writing the documentation.</p>");
-					sb.Append ("<p>When you are happy with your changes, use the menu File--&gt; Contributions--&gt; Upload to upload your contributions to our server.</p></div>");
+ 					sb.Append ("<p><b>You have not made any contributions yet.</b></p>");
+ 					sb.Append ("<p>The Documentation of the libraries is not complete and your contributions would be greatly appreciated. The procedure is easy, browse to the part of the documentation you want to contribute to and click on the <font color=\"blue\">[Edit]</font> link to start writing the documentation.</p>");
+ 					sb.Append ("<p>When you are happy with your changes, use the Contributing--&gt; Upload Contributions menu to send your contributions to our server.</p></div>");
 				} else {
 					sb.Append (con.ToString ());
 				}
